Pull Request Checklist. Please read and check each box with an X. Delete any part not applicable.

*Describe what you did in this PR and why you did it.*

### Before your first pull request:

* [ ] I have read the guidelines in our [CONTRIBUTING.md](../main/CONTRIBUTING.md) document.

### For new features/models or changes of existing features:

* [ ] I have tested my new feature locally to ensure it is correct.
* [ ] I have created an example for the new feature/benchmark in the [examples/](../main/examples/) directory.
* [ ] I have added a changelog entry in the [doc/modules/changes](../main/docs/changes) directory that will inform other users of my change.
